@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoLastBoss.cpp,v 1.10 2009/01/04 00:26:03 bowkenken Exp $
+* $Id: DemoLastBoss.cpp,v 1.11 2009/06/06 05:37:51 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -162,34 +162,26 @@ bool DemoLastBoss::draw()
 	case LAST_SCENE_N_ENCOUNTER:
 		break;
 	case LAST_SCENE_N_ENCOUNTER_CUT_IN:
-		gui_begin();
 		flag = drawCutIn( true, true, true );
-		gui_end();
 		break;
 	case LAST_SCENE_N_ENCOUNTER_WORDS:
 		drawCutIn( true, true, true );
 		break;
 	case LAST_SCENE_N_ENCOUNTER_CUT_OUT:
-		gui_begin();
 		flag = drawCutOut( true, true, true );
-		gui_end();
 		break;
 	case LAST_SCENE_N_ENCOUNTER_CUT_END:
 	case LAST_SCENE_N_EXEL:
 	case LAST_SCENE_N_EXEL_ENTER:
 		break;
 	case LAST_SCENE_N_EXEL_CUT_IN:
-		gui_begin();
 		flag = drawCutIn( true, false, false );
-		gui_end();
 		break;
 	case LAST_SCENE_N_EXEL_WORDS:
 		drawCutIn( true, false, false );
 		break;
 	case LAST_SCENE_N_EXEL_CUT_OUT:
-		gui_begin();
 		flag = drawCutOut( true, false, false );
-		gui_end();
 		break;
 	case LAST_SCENE_N_EXEL_CUT_END:
 	case LAST_SCENE_N_EXEL_HYPER:
@@ -198,17 +190,13 @@ bool DemoLastBoss::draw()
 	case LAST_SCENE_N_EXELER:
 		break;
 	case LAST_SCENE_N_EXELER_CUT_IN:
-		gui_begin();
 		flag = drawCutIn( false, true, false );
-		gui_end();
 		break;
 	case LAST_SCENE_N_EXELER_WORDS:
 		drawCutIn( false, true, false );
 		break;
 	case LAST_SCENE_N_EXELER_CUT_OUT:
-		gui_begin();
 		flag = drawCutOut( false, true, false );
-		gui_end();
 		break;
 	case LAST_SCENE_N_EXELER_CUT_END:
 	case LAST_SCENE_N_EXELER_ENTER:
@@ -218,17 +206,13 @@ bool DemoLastBoss::draw()
 	case LAST_SCENE_N_XEX:
 		break;
 	case LAST_SCENE_N_XEX_CUT_IN:
-		gui_begin();
 		flag = drawCutIn( false, false, true );
-		gui_end();
 		break;
 	case LAST_SCENE_N_XEX_WORDS:
 		drawCutIn( false, false, true );
 		break;
 	case LAST_SCENE_N_XEX_CUT_OUT:
-		gui_begin();
 		flag = drawCutOut( false, false, true );
-		gui_end();
 		break;
 	case LAST_SCENE_N_XEX_CUT_END:
 	case LAST_SCENE_N_XX_ENTER:
@@ -293,10 +277,12 @@ bool DemoLastBoss::incFrame( long maxFrame )
 {
 	frame++;
 
-	if( frame >= maxFrame )
+	if( frame > maxFrame ){
+		frame = maxFrame;
 		return true;
-	else
+	} else {
 		return false;
+	}
 }
 
 ////////////////////////////////////////////////////////////////
