@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: FileList.cpp,v 1.21 2008/09/06 12:07:52 bowkenken Exp $
+* $Id: FileList.cpp,v 1.23 2009/01/04 00:26:03 bowkenken Exp $
 ***************************************************************/
 
 #ifdef D_WS
@@ -289,7 +289,7 @@ WSCstring FileList::setStrDirSelGraph( WSCstring dir )
 {
 	sDirBaseSelGraph = jointDir( "graph/", dir );
 
-	return dir;
+	return sDirBaseSelGraph;
 }
 
 ////////////////////////////////////////////////////////////////
@@ -302,7 +302,20 @@ WSCstring FileList::setStrDirSelMusic( WSCstring dir )
 {
 	sDirBaseSelGraph = jointDir( "music/", dir );
 
-	return dir;
+	return sDirBaseSelGraph;
+}
+
+////////////////////////////////////////////////////////////////
+// ǥ쥯ȥꤹ (SE)
+// WSCstring dir : ǥ쥯ȥ
+// return : ǥ쥯ȥ
+////////////////////////////////////////////////////////////////
+
+WSCstring FileList::setStrDirSelSound( WSCstring dir )
+{
+	sDirBaseSelGraph = jointDir( "sound/", dir );
+
+	return sDirBaseSelGraph;
 }
 
 ////////////////////////////////////////////////////////////////
