@@ -26,7 +26,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GameMusic.cpp,v 1.26 2009/01/04 00:26:03 bowkenken Exp $
+* $Id: GameMusic.cpp,v 1.27 2009/06/03 19:25:22 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -709,7 +709,7 @@ WSCstring GameMusic::playRandm(
 
 void donePlayEnding()
 {
-	change_scene( SCENE_N_ENDING_STAFF_ROLL );
+	change_scene_gui( SCENE_N_ENDING_STAFF_ROLL );
 	gMusic.playTheEnd( 0 );
 }
 
