@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiChrSheet.cpp,v 1.24 2009/06/01 06:29:57 bowkenken Exp $
+* $Id: GuiChrSheet.cpp,v 1.25 2009/06/03 18:09:10 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -168,7 +168,7 @@ void GuiChrSheet::newWinMisc()
 
 	static char name[16 + MBR_NAME_MAX_BYTE + 1];
 	sn_printf( name, 16 + MBR_NAME_MAX_BYTE, "name : %*s",
-			MBR_NAME_MAX_BYTE, " " );
+			MBR_NAME_MAX_LEN, " " );
 
 	mName = gtk_label_new( name );
 	if( mName == NULL ){
@@ -440,7 +440,7 @@ void GuiChrSheet::newWinStatTab()
 
 	static char str[RACE_STR_MAX_BYTE + 1];
 	sn_printf( str, RACE_STR_MAX_BYTE, "%*s",
-			RACE_STR_MAX_BYTE, " " );
+			RACE_STR_MAX_LEN, " " );
 	mStatRace = gtk_button_new_with_label( str );
 	if( mStatRace == NULL ){
 		print_msg( FLG_MSG_ERR, "gtk_button_new_with_label()" );
@@ -918,7 +918,7 @@ void GuiChrSheet::newWinAblTab()
 	// 饹
 
 	sn_printf( str, CLASS_NAME_MAX_BYTE, "%*s",
-			CLASS_NAME_MAX_BYTE, " " );
+			CLASS_NAME_MAX_LEN, " " );
 	mAblClass = gtk_button_new_with_label( str );
 	if( mAblClass == NULL ){
 		print_msg( FLG_MSG_ERR, "gtk_button_new_with_label()" );
@@ -1599,7 +1599,7 @@ void GuiChrSheet::newWinSkillTab( long page )
 	// 饹
 
 	sn_printf( str, CLASS_NAME_MAX_BYTE, "%*s",
-			CLASS_NAME_MAX_BYTE, " " );
+			CLASS_NAME_MAX_LEN, " " );
 	mSkillClass = gtk_button_new_with_label( str );
 	if( mSkillClass == NULL ){
 		print_msg( FLG_MSG_ERR, "gtk_button_new_with_label()" );
@@ -1716,7 +1716,7 @@ void GuiChrSheet::newWinSkillTab( long page )
 
 		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
 				"%*s",
-				SKILL_NAME_MAX_BYTE, " " );
+				SKILL_NAME_MAX_LEN, " " );
 		mSkillName[page][i] = gtk_button_new_with_label( str );
 		if( mSkillName[page][i] == NULL ){
 			print_msg( FLG_MSG_ERR,
@@ -1921,7 +1921,7 @@ void GuiChrSheet::newWinItemTab()
 
 		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
 				"%*s",
-				ITEM_NAME_MAX_BYTE, " " );
+				ITEM_NAME_MAX_LEN, " " );
 		mItemName[i] = gtk_label_new( str );
 		if( mItemName[i] == NULL ){
 			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
@@ -2028,7 +2028,7 @@ void GuiChrSheet::newWinEquipTab()
 
 		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
 				"%*s",
-				ITEM_NAME_MAX_BYTE, " " );
+				ITEM_NAME_MAX_LEN, " " );
 		mEquipName[i] = gtk_label_new( str );
 		if( mEquipName[i] == NULL ){
 			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
