@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiStat.cpp,v 1.28 2009/06/01 06:29:57 bowkenken Exp $
+* $Id: GuiStat.cpp,v 1.29 2009/06/03 18:09:10 bowkenken Exp $
 ***************************************************************/
 
 #define GUI_STAT_CPP
@@ -242,10 +242,10 @@ void GuiStat::newWinMbr( mbr_t *mbr, GtkWidget *vBox )
 	long nHp, nMp, nMaxHp, nMaxMp;
 	static char buf[80 * 8 + 1];
 
-	sprintf( buf, "%*c", MBR_NAME_MAX_BYTE, ' ' );
+	sprintf( buf, "%*c", MBR_NAME_MAX_LEN, ' ' );
 	sName = buf;
 
-	sprintf( buf, "%*c", ACT_MSG_MAX_BYTE, ' ' );
+	sprintf( buf, "%*c", ACT_MSG_MAX_LEN, ' ' );
 	sAct = buf;
 
 	sprintf( buf, "%*c", WIN_STAT_DRAW_WIDTH, ' ' );
