@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiStat.h,v 1.12 2009/01/04 00:26:03 bowkenken Exp $
+* $Id: GuiStat.h,v 1.13 2009/05/12 04:08:16 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GUI_STAT_H
@@ -66,6 +66,10 @@ private:
 	GtkWidget *hBoxHp[MBR_MAX_N];
 	GtkWidget *hBoxMp[MBR_MAX_N];
 
+	GtkWidget *vBoxMisc;
+	GtkWidget *labelDunLev;
+	GtkWidget *labelTime;
+
 	GdkGC *mFgGcHp[MBR_MAX_N];
 	GdkGC *mFgGcMp[MBR_MAX_N];
 	GdkGC *mBgGcHp[MBR_MAX_N];
@@ -102,6 +106,8 @@ public:
 
 	void redraw( bool flagAdj = true, bool flagExpose = false );
 	void draw( long n, bool flagExpose = false );
+	void drawMisc();
+
 	WSCstring getStatStr( mbr_t *mbr );
 
 // ץ饤١ȡСؿ
