@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Key.h,v 1.11 2008/09/27 06:16:16 bowkenken Exp $
+* $Id: Key.h,v 1.13 2009/01/04 00:26:03 bowkenken Exp $
 ***************************************************************/
 
 #ifndef KEY_H
@@ -79,8 +79,10 @@ public:
 
 	bool moveCrsrRel( long mapX, long mapY );
 	bool moveCrsrAbs( long mapX, long mapY );
+	void CheckMoveCrsr();
 	bool scrollRel( long mapX, long mapY );
 	bool scrollAbs( long mapX, long mapY );
+	void CheckScroll();
 
 #ifdef D_MFC
 	void handleKeyDown(
