@@ -75,7 +75,7 @@ bool_t	call_pcg_dun_clip_win_x( long mapX );
 bool_t	call_pcg_dun_clip_win_y( long mapY );
 void	call_demo_last_boss_reset( void );
 bool_t	call_demo_last_boss_check_done( void );
-void	call_game_music_play_scene( void );
+void	call_game_music_play_scene( bool_t flg_gui );
 void	call_game_music_play( long kind, long idx );
 void	call_game_music_replay( void );
 void	call_game_sound_play( long kind, long n );
