@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.104 2009/06/03 19:25:12 bowkenken Exp $
+* $Id: call.cpp,v 1.105 2009/06/06 10:18:49 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -967,10 +967,11 @@ void	call_pcg_dun_draw_string(
 {
 #if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
 	va_list	argptr;
-	static char	buf[SCREEN_WIDTH * 2 + 1];
+	static char	buf[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
+	const long	max_len = SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8;
 
 	va_start( argptr, s );
-	vsn_printf( buf, SCREEN_WIDTH * 2, s, argptr );
+	vsn_printf( buf, max_len, s, argptr );
 	va_end( argptr );
 
 	if( !g_flg_init )
