@@ -6,7 +6,16 @@ extern "C" {
 
 void	init_chr( void );
 void	reset_static_chr( void );
+bool_t	chk_flg_run_exec_all_phase( void );
 void	exec_all_phase( void );
+void	clr_chr_find( void );
+void	chk_chr_find( void );
+void	set_flg_mbr_find_mnstr( bool_t flg_find );
+void	set_flg_mnstr_find_mbr( bool_t flg_find );
+void	set_flg_boss_find_mbr( bool_t flg_find );
+bool_t	chk_flg_mbr_find_mnstr( void );
+bool_t	chk_flg_mnstr_find_mbr( void );
+bool_t	chk_flg_boss_find_mbr( void );
 void	last_boss_phase( void );
 void	draw_phase( bool_t flg_first_phase );
 void	move_phase_chr( chr_t *chr );
