@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: dun.c,v 1.147 2009/03/13 15:00:30 bowkenken Exp $
+* $Id: dun.c,v 1.151 2009/06/01 05:05:04 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -376,18 +376,7 @@ void	up_dun( long d )
 			menu_save_n( FALSE, SAVE_N_AUTO );
 	}
 
-	if( sgn_l( dun.lev ) >= +1 ){
-		print_msg( FLG_NULL, MSG_UP_DOWN_DUN_FLOOR,
-				labs( dun.lev ) );
-		change_scene( SCENE_N_DUN );
-	} else if( sgn_l( dun.lev ) <= -1 ){
-		print_msg( FLG_NULL, MSG_UP_DOWN_DUN_BASE,
-				labs( dun.lev ) );
-		change_scene( SCENE_N_DUN );
-	} else {
-		print_msg( FLG_NULL, MSG_UP_DOWN_DUN_GROUND );
-		change_scene( SCENE_N_TOWN );
-	}
+	up_dun_msg();
 
 	/* Сãؤ򹹿 */
 
@@ -413,6 +402,26 @@ void	up_dun( long d )
 	reset_all( TRUE );
 }
 
+/***************************************************************
+* µܤ겼ꤷݤΥåɽȥڤؤ
+***************************************************************/
+
+void	up_dun_msg( void )
+{
+	if( sgn_l( dun.lev ) >= +1 ){
+		print_msg( FLG_NULL, MSG_UP_DOWN_DUN_FLOOR,
+				labs( dun.lev ) );
+		change_scene( SCENE_N_DUN );
+	} else if( sgn_l( dun.lev ) <= -1 ){
+		print_msg( FLG_NULL, MSG_UP_DOWN_DUN_BASE,
+				labs( dun.lev ) );
+		change_scene( SCENE_N_DUN );
+	} else {
+		print_msg( FLG_NULL, MSG_UP_DOWN_DUN_GROUND );
+		change_scene( SCENE_N_TOWN );
+	}
+}
+
 /***************************************************************
 * 饹ܥγؤ
 ***************************************************************/
@@ -433,7 +442,7 @@ void	reset_all_save( bool_t flg_appear )
 {
 	srandm( g_randm_seed_save );
 
-	reset_all( flg_appear );
+	reset_all( TRUE );
 }
 
 /***************************************************************
@@ -2647,53 +2656,50 @@ void	set_map_total_obj( long x, long y, long dx, long dy )
 
 void	set_map_total_square( long x, long y, long dx, long dy )
 {
-	long	i, j;
-	long	xx, yy;
-	curs_attr_t	*attr_dflt;
+	long	i;
+
+	for( i = 0; i < MBR_MAX_N; i++ )
+		set_map_total_square_n( i, x, y, dx, dy );
+}
+
+/***************************************************************
+* 󥫡Υޥåפ쥤䡼򹹿
+* long mbr_n : Сֹ
+* long x : X ɸ
+* long y : Y ɸ
+* long dx : 
+* long dy : ⤵
+***************************************************************/
+
+void	set_map_total_square_n(
+	long mbr_n, long x, long y, long dx, long dy
+)
+{
+	long	sq_x, sq_y;
 	party_t	*pty;
+	curs_attr_t	*attr_dflt;
+
+	get_square_mbr_map_pos( mbr_n, &sq_x, &sq_y );
+	if( !clip_pos( sq_x, sq_y ) )
+		return;
+	if( sq_x < x )
+		return;
+	if( sq_y < y )
+		return;
+	if( sq_x > (x + dx - 1) )
+		return;
+	if( sq_y > (y + dy - 1) )
+		return;
 
 	pty = get_party();
-
-	if( !clip_pos( pty->square.x, pty->square.y ) )
-		return;
-	if( (pty->square.x + 1) < x )
-		return;
-	if( (pty->square.y + 1) < y )
-		return;
-	if( (pty->square.x - 1) > (x + dx - 1) )
-		return;
-	if( (pty->square.y - 1) > (y + dy - 1) )
-		return;
+	dun.map.total.mjr[sq_y][sq_x] = FACE_MJR_SQUARE;
+	if( chk_flg( pty->mbr[mbr_n]->stat, FLG_STAT_NOT_EXIST ) )
+		dun.map.total.mnr[sq_y][sq_x] = FACE_MNR_NULL;
+	else
+		dun.map.total.mnr[sq_y][sq_x] = pty->mbr[mbr_n]->face.mnr;
 
 	attr_dflt = get_curs_attr();
-
-	for( i = -1; i <= +1; i++ ){
-		yy = pty->square.y + i;
-		if( !clip_y( yy ) )
-			continue;
-
-		for( j = -1; j <= +1; j++ ){
-			mbr_t	*mbr;
-
-			xx = pty->square.x + j;
-			if( !clip_x( xx ) )
-				continue;
-
-			if( pty->square.chr_dir[i + 1][j + 1] == MBR_NO_POS )
-				continue;
-
-			dun.map.total.mjr[yy][xx] = FACE_MJR_SQUARE;
-			dun.map.attr[yy][xx]
-					= attr_dflt[CURS_ATTR_N_MAP_SQUARE];
-
-			mbr = pty->mbr[pty->square.chr_dir[i + 1][j + 1]];
-			if( chk_flg( mbr->stat, FLG_STAT_NOT_EXIST ) ){
-				continue;
-			}
-
-			dun.map.total.mnr[yy][xx] = mbr->face.mnr;
-		}
-	}
+	dun.map.attr[sq_y][sq_x] = attr_dflt[CURS_ATTR_N_MAP_SQUARE];
 }
 
 /***************************************************************
@@ -3907,6 +3913,8 @@ bool_t	up_stairs( void )
 		return FALSE;
 	}
 
+	call_game_sound_play( SOUND_KIND_STAIRS_UP, 1 );
+
 	print_msg( FLG_NULL, MSG_UP_DUN );
 	up_dun( +1 );
 
@@ -3928,6 +3936,8 @@ bool_t	down_stairs( void )
 		return FALSE;
 	}
 
+	call_game_sound_play( SOUND_KIND_STAIRS_DOWN, 1 );
+
 	print_msg( FLG_NULL, MSG_DOWN_DUN );
 	up_dun( -1 );
 
