@@ -43,6 +43,8 @@ void	rc_lex_id( FILE *fp, rc_union_t *u, bool_t flg_err_exit );
 long	rc_lex_getc( FILE *fp, bool_t flg_chk_eof, bool_t flg_err_exit );
 void	rc_lex_ungetc( FILE *fp, long c );
 bool_t	rename_back_up_file( char *fname );
+square_dir_t	trans_idx_to_square_dir( long idx );
+long	trans_square_dir_to_idx( square_dir_t dir );
 chr_kind_t	trans_idx_to_chr_kind( long idx );
 long	trans_chr_kind_to_idx( chr_kind_t k );
 main_race_t	trans_idx_to_main_race_kind( long idx );
@@ -156,6 +158,7 @@ long	save_crypt_tab( FILE *fp, const char *s, ... );
 long	save_crypt_str( FILE *fp, const char *s, ... );
 long	load_crypt_str( FILE *fp, char *buf, long n );
 long	load_crypt_c( FILE *fp );
+long	load_crypt_c_sub( FILE *fp );
 void	un_load_crypt_c( FILE *fp, long c );
 
 #ifdef __cplusplus
@@ -168,6 +171,8 @@ extern "C" {
 #endif
 
 bool_t	load_game_conf( void );
+void	ver_up_game_conf_1_0_15( void );
+void	ver_up_game_data_cnf_1_2_22( void );
 bool_t	load_game_conf_head( FILE *fp, ver_t *ver );
 void	load_game_conf_data_ver_1( FILE *fp, const ver_t *ver );
 bool_t	load_game_conf_parse_ver_1( FILE *fp, const ver_t *ver );
@@ -203,6 +208,8 @@ bool_t	load_game_conf_space_select( char *id, long val );
 bool_t	load_game_conf_redraw_every_turn( char *id, long val );
 bool_t	load_game_conf_mul_line( char *id, long val );
 bool_t	load_game_conf_joystick_number( char *id, long val );
+bool_t	load_game_conf_gnome( char *id, long val );
+bool_t	load_game_conf_set_window_position( char *id, long val );
 bool_t	load_game_conf_win_pos( char *id, long val, win_kind_t kind );
 bool_t	load_game_conf_vfx_mbr( flg_vfx_mbr_t flg, long val );
 bool_t	load_game_conf_vfx_mnstr( flg_vfx_mnstr_t flg, long val );
@@ -247,6 +254,8 @@ bool_t	save_game_conf_frame_rate( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_screen_size( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_scroll( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_flg( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_gnome( FILE *fp, const ver_t *ver );
+bool_t	save_game_conf_set_window_position( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_win_pos( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_joystick( FILE *fp, const ver_t *ver );
 bool_t	save_game_conf_vfx( FILE *fp, const ver_t *ver );
@@ -367,6 +376,9 @@ extern "C" {
 #endif
 
 bool_t	load_game_data( bool_t flg_txt, long n );
+void	set_flg_load_game_data( bool_t flg );
+bool_t	get_flg_load_game_data( void );
+void	appear_load_game_data( long slot_n );
 void	ver_up_game_data_1_0_4( void );
 void	ver_up_game_data_1_1_1( void );
 void	ver_up_game_data_1_1_3( void );
@@ -395,6 +407,9 @@ bool_t	load_game_data_block_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	char *id, long n
 );
+bool_t	load_game_data_square_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
 bool_t	load_game_data_class_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt,
 	long n
@@ -586,6 +601,9 @@ bool_t	save_game_data_dun_lev_ver_1(
 bool_t	save_game_data_turn_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
+bool_t	save_game_data_square_ver_1(
+	FILE *fp, const ver_t *ver, bool_t flg_txt
+);
 bool_t	save_game_data_class_ver_1(
 	FILE *fp, const ver_t *ver, bool_t flg_txt
 );
