@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gfile.h,v 1.20 2009/01/04 00:24:52 bowkenken Exp $
+* $Id: gfile.h,v 1.22 2009/05/28 07:29:09 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	GFILE_H
@@ -178,9 +178,13 @@ EXTERN rc_token_t	g_un_token;
 EXTERN rc_union_t	g_un_union;
 EXTERN bool_t	g_flg_crypt_txt;
 
+EXTERN long	g_rc_lex_num_mode;
+
 EXTERN curs_attr_n_t	g_crnt_attr_n;
 
 EXTERN long	g_game_data_save_n;
 EXTERN replay_kind_t	g_replay_kind_cur;
+EXTERN long	g_load_slot_n;
+EXTERN bool_t	g_flg_load_game_data;
 
 #endif	/* GFILE_H */
