@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.129 2009/05/28 07:29:09 bowkenken Exp $
+* $Id: gmain.c,v 1.130 2009/06/03 17:21:26 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -286,12 +286,18 @@ void	game_main( void )
 
 	if( g_flg_debug ){
 		menu_load_wiz();
+
+		if( !g_flg_gui && g_flg_cui )
+			change_scene( SCENE_N_TOWN );
 	} else {
 		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_1 );
 		print_msg( FLG_NULL, MSG_HINT_CANCEL_MENU_2 );
 
 		menu_load_start();
 
+		if( !g_flg_gui && g_flg_cui )
+			change_scene( SCENE_N_TOWN );
+
 		if( g_load_slot_n != SAVE_N_AUTO )
 			party_exit_bar();
 	}
