@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: last-boss.c,v 1.72 2009/05/31 08:35:54 bowkenken Exp $
+* $Id: last-boss.c,v 1.73 2009/06/06 12:29:12 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -2691,7 +2691,7 @@ void	xx_act_heat_draw( mnstr_t *p )
 		if( xx_heat.head_y > end_y )
 			break;
 
-		if( g_flg_cui && !g_flg_gui )
+		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
 			redraw_map();
 
 		if( (xx_heat.head_y % XX_HEAT_DY) == 0 ){
@@ -2804,7 +2804,7 @@ void	xx_act_cold_draw( mnstr_t *p )
 	for( i = 0; i < LOOP_MAX_100; i++ ){
 		bool_t	flg_next;
 
-		if( g_flg_cui && !g_flg_gui )
+		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
 			redraw_map();
 
 		flg_next = TRUE;
@@ -2846,7 +2846,7 @@ void	xx_act_cold_draw( mnstr_t *p )
 	/* 졼ȯͤ */
 
 	for( i = 0; i < LOOP_MAX_100; i++ ){
-		if( g_flg_cui && !g_flg_gui )
+		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
 			redraw_map();
 
 		for( n = 0; n < MBR_MAX_N; n++ ){
@@ -2865,7 +2865,16 @@ void	xx_act_cold_draw( mnstr_t *p )
 				x += (xx_laser_dxy[n].x * j);
 				y += (xx_laser_dxy[n].y * j);
 
-				print_vfx_cui( x, y, MSG_S, xx_laser[n] );
+				if( g_flg_text_mode )
+					curs_attrset_n( CURS_ATTR_N_COLD );
+
+				if( g_flg_gui && g_flg_text_mode ){
+					print_vfx( x, y, MSG_S,
+							xx_laser[n] );
+				} else {
+					print_vfx_cui( x, y, MSG_S,
+							xx_laser[n] );
+				}
 			}
 			curs_attrset_dflt();
 
@@ -2948,7 +2957,7 @@ void	xx_act_mind_draw( mnstr_t *p )
 	/*  */
 
 	for( i = 0; i < LOOP_MAX_100; i++ ){
-		if( g_flg_cui && !g_flg_gui )
+		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
 			redraw_map();
 
 		/* ư */
@@ -3071,7 +3080,13 @@ static void xx_mind_draw( xx_mind_t *xx_mind )
 			else
 				str = xx_refract_image;
 
-			print_vfx_cui( x, y, MSG_S, str );
+			if( g_flg_text_mode )
+				curs_attrset_n( CURS_ATTR_N_MIND );
+
+			if( g_flg_gui && g_flg_text_mode )
+				print_vfx( x, y, MSG_S, str );
+			else
+				print_vfx_cui( x, y, MSG_S, str );
 		}
 	}
 	curs_attrset_dflt();
@@ -3157,7 +3172,7 @@ void	xx_act_acid_draw( mnstr_t *p )
 	/*  */
 
 	for( i = 0; i < LOOP_MAX_100; i++ ){
-		if( g_flg_cui && !g_flg_gui )
+		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
 			redraw_map();
 
 		if( xx_acid_chk_end( &xx_acid ) )
@@ -3337,7 +3352,13 @@ static void xx_acid_draw( xx_acid_t *xx_acid )
 			else
 				str = xx_homing_image;
 
-			print_vfx_cui( x, y, MSG_S, str );
+			if( g_flg_text_mode )
+				curs_attrset_n( CURS_ATTR_N_ACID );
+
+			if( g_flg_gui && g_flg_text_mode )
+				print_vfx( x, y, MSG_S, str );
+			else
+				print_vfx_cui( x, y, MSG_S, str );
 		}
 	}
 	curs_attrset_dflt();
@@ -3421,7 +3442,7 @@ void	xx_act_rotation_draw( mnstr_t *p )
 			}
 		}
 
-		if( g_flg_cui && !g_flg_gui )
+		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
 			redraw_map();
 
 		curs_attrset_n( CURS_ATTR_N_COLD );
@@ -3435,7 +3456,17 @@ void	xx_act_rotation_draw( mnstr_t *p )
 				x -= draw->x;
 				y -= draw->y;
 				x *= 2;
-				print_vfx_cui( x, y, MSG_S, xx_rotation_str );
+
+				if( g_flg_text_mode )
+					curs_attrset_n( CURS_ATTR_N_COLD );
+
+				if( g_flg_gui && g_flg_text_mode ){
+					print_vfx( x, y, MSG_S,
+							xx_rotation_str );
+				} else {
+					print_vfx_cui( x, y, MSG_S,
+							xx_rotation_str );
+				}
 			}
 		}
 		curs_attrset_dflt();
@@ -3577,7 +3608,7 @@ void	xx_act_whirl_draw( mnstr_t *p )
 			xx_whirl.y[n] = y;
 		}
 
-		if( g_flg_cui && !g_flg_gui )
+		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
 			redraw_map();
 
 		curs_attrset_n( CURS_ATTR_N_HEAT );
@@ -3591,7 +3622,13 @@ void	xx_act_whirl_draw( mnstr_t *p )
 			y -= draw->y;
 			x *= 2;
 
-			print_vfx_cui( x, y, MSG_S, xx_whirl_str );
+			if( g_flg_text_mode )
+				curs_attrset_n( CURS_ATTR_N_HEAT );
+
+			if( g_flg_gui && g_flg_text_mode )
+				print_vfx( x, y, MSG_S, xx_whirl_str );
+			else
+				print_vfx_cui( x, y, MSG_S, xx_whirl_str );
 		}
 		curs_attrset_dflt();
 
@@ -3711,7 +3748,7 @@ void	xx_act_fan_draw( mnstr_t *p )
 			}
 		}
 
-		if( g_flg_cui && !g_flg_gui )
+		if( g_flg_text_mode || (g_flg_cui && !g_flg_gui) )
 			redraw_map();
 
 		curs_attrset_n( CURS_ATTR_N_MIND );
@@ -3726,7 +3763,16 @@ void	xx_act_fan_draw( mnstr_t *p )
 				y -= draw->y;
 				x *= 2;
 
-				print_vfx_cui( x, y, MSG_S, xx_fan_str );
+				if( g_flg_text_mode )
+					curs_attrset_n( CURS_ATTR_N_MIND );
+
+				if( g_flg_gui && g_flg_text_mode ){
+					print_vfx( x, y, MSG_S,
+							xx_fan_str );
+				} else {
+					print_vfx_cui( x, y, MSG_S,
+							xx_fan_str );
+				}
 			}
 		}
 		curs_attrset_dflt();
