@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-gtk.cpp,v 1.65 2009/06/03 19:25:22 bowkenken Exp $
+* $Id: main-gtk.cpp,v 1.66 2009/06/06 10:19:03 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -524,11 +524,12 @@ void	closeGameGui()
 
 void	printMapStatBar( const char *s, ... )
 {
-	static char	str[SCREEN_WIDTH * 2 + 1];
+	static char	str[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
+	const long	max_len = SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8;
 	va_list	argptr;
 
 	va_start( argptr, s );
-	vsprintf( str, s, argptr );
+	vsn_printf( str, max_len, s, argptr );
 	va_end( argptr );
 
 	gtk_statusbar_remove(
