@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr-act.c,v 1.16 2008/04/16 16:12:34 bowkenken Exp $
+* $Id: mnstr-act.c,v 1.29 2009/01/31 11:25:27 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -304,6 +304,9 @@ void	set_act_towner_exit_door( mnstr_t *p )
 
 void	set_act_mnstr_friendly( mnstr_t *p )
 {
+	if( p == NULL )
+		return;
+
 	if( set_act_tame_mnstr( p ) )
 		return;
 
@@ -616,6 +619,8 @@ void	set_act_mnstr_giant_rat( mnstr_t *p )
 			increase_turn = get_turn();
 		}
 	}
+
+	static_set_act_mnstr_giant_rat__increase_turn = increase_turn;
 }
 
 /*  */
@@ -751,7 +756,7 @@ void	set_act_mnstr_gargoyle( mnstr_t *p )
 
 		/* Ṳ̄ͤˤ */
 		flg_map = dun->map.obj.flg[p->y][p->x];
-		dun->map.obj.flg[p->y][p->x] |= FLG_MAP_OBJ_PASS;
+		dun->map.obj.flg[p->y][p->x] |= FLG_MAP_OBJ_LOOK;
 
 		/* СܤƤ뤫å */
 		mark = mnstr_mark_mbr_adjoin( p );
@@ -763,7 +768,9 @@ void	set_act_mnstr_gargoyle( mnstr_t *p )
 		if( mark != NULL ){
 			dun->map.obj.mjr[p->y][p->x] = FACE_MJR_FLOOR;
 			dun->map.obj.mnr[p->y][p->x] = FACE_MNR_FLOOR;
-			dun->map.obj.flg[p->y][p->x] = FLG_MAP_OBJ_PASS;
+			dun->map.obj.flg[p->y][p->x]
+					= (FLG_MAP_OBJ_PASS
+					| FLG_MAP_OBJ_LOOK);
 		}
 	}
 
@@ -839,3 +846,63 @@ void	set_act_mnstr_succubus( mnstr_t *p )
 /*  */
 /*  */
 
+/***************************************************************
+* Υ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
+void	set_act_mnstr_exel( mnstr_t *p )
+{
+	if( p == NULL )
+		return;
+
+	if( get_last_scene() != LAST_SCENE_N_EXEL_BATTLE ){
+		p->stat |= FLG_STAT_IRON_BODY;
+		p->abl.hp.n = p->abl.hp.max;
+	} else {
+		p->stat &= ~FLG_STAT_IRON_BODY;
+		set_act_mnstr_std( p );
+	}
+}
+
+/***************************************************************
+* 顼Υ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
+void	set_act_mnstr_exeler( mnstr_t *p )
+{
+	if( p == NULL )
+		return;
+
+	if( get_last_scene() != LAST_SCENE_N_EXELER_BATTLE ){
+		p->stat |= FLG_STAT_IRON_BODY;
+		p->abl.hp.n = p->abl.hp.max;
+	} else {
+		p->stat &= ~FLG_STAT_IRON_BODY;
+		set_act_mnstr_std( p );
+	}
+}
+
+/***************************************************************
+* Υ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
+void	set_act_mnstr_xex( mnstr_t *p )
+{
+	if( p == NULL )
+		return;
+
+	p->stat |= FLG_STAT_IRON_BODY;
+	p->abl.hp.n = p->abl.hp.max;
+}
+
+/***************************************************************
+* ȥƥΥ
+* mnstr_t *p : 󥹥
+***************************************************************/
+
+void	set_act_mnstr_xx( mnstr_t *p )
+{
+}
