@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.224 2009/06/01 05:05:04 bowkenken Exp $
+* $Id: mnstr.c,v 1.225 2009/06/06 08:04:22 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -1584,9 +1584,10 @@ void	die_mnstr_drop_item( mnstr_t *p )
 /***************************************************************
 * 󥹥ν
 * mnstr_t *p : 󥹥
+* bool_t flg_msg : åɸ뤫?
 ***************************************************************/
 
-void	die_mnstr( mnstr_t *p )
+void	die_mnstr( mnstr_t *p, bool_t flg_msg )
 {
 	if( p == NULL )
 		return;
@@ -1594,10 +1595,13 @@ void	die_mnstr( mnstr_t *p )
 		return;
 
 	if( is_pet( p ) ){
-		die_pet( p );
+		die_pet( p, flg_msg );
 		return;
 	}
 
+	if( !flg_msg )
+		return;
+
 	if( is_xx( p ) ){
 		call_game_sound_play(
 				SOUND_KIND_FIGHT_DIE_MONSTER_BOSS_LAST,
