@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: party.c,v 1.234 2009/06/01 05:05:04 bowkenken Exp $
+* $Id: party.c,v 1.235 2009/06/06 08:04:22 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -2107,7 +2107,7 @@ bool_t	chk_auto_door_mbr_sub( mbr_t *mbr, long x, long y )
 
 /**/
 
-void	die_mbr( mbr_t *mbr, bool_t flg_chk_game_over )
+void	die_mbr( mbr_t *mbr, bool_t flg_msg, bool_t flg_chk_game_over )
 {
 	long	i;
 
@@ -2116,7 +2116,8 @@ void	die_mbr( mbr_t *mbr, bool_t flg_chk_game_over )
 	if( !is_mbr( mbr ) )
 		return;
 
-	call_game_sound_play( SOUND_KIND_FIGHT_DIE_MEMBER, 1 );
+	if( flg_msg )
+		call_game_sound_play( SOUND_KIND_FIGHT_DIE_MEMBER, 1 );
 
 	if( !flg_chk_game_over )
 		return;
