@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: pet.c,v 1.65 2009/05/31 07:23:45 bowkenken Exp $
+* $Id: pet.c,v 1.66 2009/06/06 08:04:22 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -692,14 +692,16 @@ void	garbage_collection_all_pet( void )
 /***************************************************************
 * ڥåȤν
 * pet_t *p : ڥå
+* bool_t flg_msg : åɸ뤫?
 ***************************************************************/
 
-void	die_pet( pet_t *p )
+void	die_pet( pet_t *p, bool_t flg_msg )
 {
 	if( p == NULL )
 		return;
 
-	call_game_sound_play( SOUND_KIND_FIGHT_DIE_MEMBER, 1 );
+	if( flg_msg )
+		call_game_sound_play( SOUND_KIND_FIGHT_DIE_MEMBER, 1 );
 }
 
 /***************************************************************
