@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: request.c,v 1.104 2009/03/04 08:12:53 bowkenken Exp $
+* $Id: request.c,v 1.111 2009/06/01 05:05:04 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -196,19 +196,33 @@ request_t	*make_request_randm( void )
 	case REQUEST_KIND_NULL:
 		break;
 	case REQUEST_KIND_RARE_GOODS:
-		return make_request_rare_goods( req );
+		if( make_request_rare_goods( req ) != NULL )
+			return req;
+		break;
 	case REQUEST_KIND_TAME_MNSTR:
-		return make_request_tame_mnstr( req );
+		if( make_request_tame_mnstr( req ) != NULL )
+			return req;
+		break;
 	case REQUEST_KIND_RESCUE:
-		return make_request_rescue( req );
+		if( make_request_rescue( req ) != NULL )
+			return req;
+		break;
 	case REQUEST_KIND_TOUR_GUIDE:
-		return make_request_tour_guide( req );
+		if( make_request_tour_guide( req ) != NULL )
+			return req;
+		break;
 	case REQUEST_KIND_EXTERMINATE:
-		return make_request_exterminate( req );
+		if( make_request_exterminate( req ) != NULL )
+			return req;
+		break;
 	case REQUEST_KIND_REVENGE:
-		return make_request_revenge( req );
+		if( make_request_revenge( req ) != NULL )
+			return req;
+		break;
 	case REQUEST_KIND_WANTED_CRIMINAL:
-		return make_request_wanted_criminal( req );
+		if( make_request_wanted_criminal( req ) != NULL )
+			return req;
+		break;
 	case REQUEST_KIND_MAX_N:
 		break;
 	}
@@ -720,7 +734,7 @@ bool_t	make_client( request_t *req, mnstr_kind_t kind, bool_t flg_now )
 	if( npc == NULL )
 		return FALSE;
 
-	str_nz_cpy( npc->name, name, CHR_NAME_MAX_LEN );
+	str_nz_cpy( npc->name, name, CHR_NAME_MAX_BYTE );
 	npc->sex.org = sex;
 	npc->sex.cur = sex;
 	npc->work.request = req;
@@ -827,6 +841,8 @@ void	set_request_dun_lev(
 
 	min_lev = labs( min_lev );
 	max_lev = labs( max_lev );
+	range_lev = labs( range_lev );
+
 	if( max_lev < min_lev ){
 		long	n;
 
@@ -1141,7 +1157,8 @@ bool_t	chk_request_limit_client( request_t *req )
 			mnstr = NULL;
 		}
 		if( mnstr != NULL ){
-			str_nz_cpy( mnstr->name, npc->name, CHR_NAME_MAX_LEN );
+			str_nz_cpy( mnstr->name, npc->name,
+					CHR_NAME_MAX_BYTE );
 			mnstr->sex.org = npc->sex.cur;
 			mnstr->sex.cur = mnstr->sex.org;
 		}
@@ -1226,8 +1243,8 @@ void	chk_set_request_npc_contract( void )
 
 bool_t	set_request_msg( request_t *req )
 {
-	static char	buf[REQUEST_MSG_MAX_LEN + 1];
-	static char	str_contract[REQUEST_MSG_MAX_LEN + 1];
+	static char	buf[REQUEST_MSG_MAX_BYTE + 1];
+	static char	str_contract[REQUEST_MSG_MAX_BYTE + 1];
 	char	*fmt;
 	long	buf_idx, fmt_idx;
 
@@ -1237,7 +1254,7 @@ bool_t	set_request_msg( request_t *req )
 	fmt = cv_idx_to_request_fmt( req );
 
 	buf[0] = '\0';
-	for( buf_idx = 0, fmt_idx = 0; buf_idx < REQUEST_MSG_MAX_LEN - 2;
+	for( buf_idx = 0, fmt_idx = 0; buf_idx < REQUEST_MSG_MAX_BYTE - 2;
 			buf_idx++, fmt_idx++ ){
 		if( fmt[fmt_idx] == '\0' ){
 			break;
@@ -1271,17 +1288,17 @@ bool_t	set_request_msg( request_t *req )
 		else
 			name = cv_idx_to_contract_name( req );
 
-		sn_printf( str_contract, REQUEST_MSG_MAX_LEN,
+		sn_printf( str_contract, REQUEST_MSG_MAX_BYTE,
 				MSG_REQUEST_CONTRACT_FMT, name );
 	} else {
 		str_nz_cpy( str_contract,
 				MSG_REQUEST_DO_NOT_CONTRACT,
-				REQUEST_MSG_MAX_LEN );
+				REQUEST_MSG_MAX_BYTE );
 	}
-	str_max_n_cat( buf, "\n", REQUEST_MSG_MAX_LEN );
-	str_max_n_cat( buf, str_contract, REQUEST_MSG_MAX_LEN );
+	str_max_n_cat( buf, "\n", REQUEST_MSG_MAX_BYTE );
+	str_max_n_cat( buf, str_contract, REQUEST_MSG_MAX_BYTE );
 
-	str_nz_cpy( req->msg, buf, REQUEST_MSG_MAX_LEN );
+	str_nz_cpy( req->msg, buf, REQUEST_MSG_MAX_BYTE );
 
 	return TRUE;
 }
@@ -1367,7 +1384,7 @@ void	set_request_msg_var_dun_min_lev(
 	if( req == NULL )
 		return;
 
-	sn_printf( buf, REQUEST_MSG_MAX_LEN, "%ld", req->dun_min_lev );
+	sn_printf( buf, REQUEST_MSG_MAX_BYTE, "%ld", req->dun_min_lev );
 }
 
 /***************************************************************
@@ -1387,7 +1404,7 @@ void	set_request_msg_var_dun_max_lev(
 	if( req == NULL )
 		return;
 
-	sn_printf( buf, REQUEST_MSG_MAX_LEN, "%ld", req->dun_max_lev );
+	sn_printf( buf, REQUEST_MSG_MAX_BYTE, "%ld", req->dun_max_lev );
 }
 
 /***************************************************************
@@ -1401,8 +1418,9 @@ void	set_request_msg_var_dun_lev_range(
 	request_t *req, char *buf, char *arg
 )
 {
-	static char	str_min[32 * 4 + 1], str_max[32 * 4 + 1];
-	long	max_len = 32 * 4;
+	static char	str_min[32 * CHAR_MAX_LEN_UTF_8 + 1];
+	static char	str_max[32 * CHAR_MAX_LEN_UTF_8 + 1];
+	long	max_len = 32 * CHAR_MAX_LEN_UTF_8;
 
 	if( buf == NULL )
 		return;
@@ -1492,7 +1510,7 @@ void	set_request_msg_var_rare_goods(
 	if( tab == NULL )
 		return;
 
-	sn_printf( buf, REQUEST_MSG_MAX_LEN,
+	sn_printf( buf, REQUEST_MSG_MAX_BYTE,
 			MSG_REQUEST_VAR_QUOTE, tab->name );
 }
 
@@ -1528,11 +1546,11 @@ void	set_request_msg_var_mnstr(
 
 		tab = get_mnstr_tab( req->mnstr_kind, req->dun_true_lev );
 		if( tab == NULL ){
-			sn_printf( buf, REQUEST_MSG_MAX_LEN,
+			sn_printf( buf, REQUEST_MSG_MAX_BYTE,
 					MSG_REQUEST_VAR_QUOTE,
 					MSG_MNSTR_UNKNOWN );
 		} else {
-			sn_printf( buf, REQUEST_MSG_MAX_LEN,
+			sn_printf( buf, REQUEST_MSG_MAX_BYTE,
 					MSG_REQUEST_VAR_QUOTE,
 					tab->name );
 		}
@@ -1556,7 +1574,7 @@ void	set_request_msg_var_mnstr_n(
 	if( req == NULL )
 		return;
 
-	sn_printf( buf, REQUEST_MSG_MAX_LEN,
+	sn_printf( buf, REQUEST_MSG_MAX_BYTE,
 			MSG_REQUEST_MNSTR_N, req->mnstr_n );
 }
 
@@ -1775,11 +1793,11 @@ void	set_request_msg_var_ls(
 		*n_msg_idx = get_ls_n_msg_idx_randm( ls_msg );
 
 	if( flg_quote ){
-		sn_printf( buf, REQUEST_MSG_MAX_LEN,
+		sn_printf( buf, REQUEST_MSG_MAX_BYTE,
 				MSG_REQUEST_VAR_QUOTE,
 				MSG( ls_msg[*n_msg_idx] ) );
 	} else {
-		sn_printf( buf, REQUEST_MSG_MAX_LEN,
+		sn_printf( buf, REQUEST_MSG_MAX_BYTE,
 				MSG_S,
 				MSG( ls_msg[*n_msg_idx] ) );
 	}
@@ -1815,7 +1833,7 @@ bool_t	set_request_heading( request_t *req )
 	name = get_request_kind_name( req->kind );
 	len = get_pading_len( name, REQUEST_NAME_MIN_LEN );
 
-	sn_printf( req->heading, MENU_MSG_MAX_LEN,
+	sn_printf( req->heading, MENU_MSG_MAX_BYTE,
 			MSG_REQUEST_HEADING_FMT,
 			str_contract,
 			len,
@@ -1972,6 +1990,8 @@ bool_t	finish_request( request_t *req )
 	if( req->flg_finish )
 		return FALSE;
 
+	call_game_sound_play( SOUND_KIND_REQUEST_FINISH, 1 );
+
 	req->flg_finish = TRUE;
 
 	curs_attrset_chr( pty->mbr[0], +1, TRUE );
@@ -2020,6 +2040,8 @@ void	chk_finish_request_chr_dead( chr_t *chr )
 	chk_finish_request_exterminate( chr->mnstr_kind, 1,
 			REQUEST_KIND_EXTERMINATE, TRUE );
 
+	put_request_rare_goods( chr );
+
 	req = chr->work.request;
 	if( req == NULL )
 		return;
@@ -2028,8 +2050,6 @@ void	chk_finish_request_chr_dead( chr_t *chr )
 	case REQUEST_KIND_NULL:
 		break;
 	case REQUEST_KIND_RARE_GOODS:
-		put_request_rare_goods( chr );
-		break;
 	case REQUEST_KIND_TAME_MNSTR:
 	case REQUEST_KIND_RESCUE:
 	case REQUEST_KIND_TOUR_GUIDE:
@@ -2599,7 +2619,7 @@ void	put_request_mnstr( void )
 		} else {
 			p->attitude = ATTITUDE_ENEMY;
 		}
-		str_nz_cpy( p->name, name, CHR_NAME_MAX_LEN );
+		str_nz_cpy( p->name, name, CHR_NAME_MAX_BYTE );
 		p->work.request = &(g_request[i]);
 		p->sex.org = sex;
 		p->sex.cur = sex;
@@ -2689,7 +2709,7 @@ char	*set_menu_request(
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	str_nz_cpy( ls[k].msg, MSG_MENU_BAR_REQUEST, MENU_MSG_MAX_LEN );
+	str_nz_cpy( ls[k].msg, MSG_MENU_BAR_REQUEST, MENU_MSG_MAX_BYTE );
 	ls[k].call_back = NULL;
 	ls[k].arg = NULL;
 	ls[k].flg = FLG_NULL;
@@ -2715,7 +2735,7 @@ char	*set_menu_request(
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
 		str_nz_cpy( ls[k].msg, g_request[i].heading,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		ls[k].call_back = cb;
 		ls[k].arg = &(g_request[i]);
 		ls[k].flg = FLG_NULL;
@@ -2730,7 +2750,7 @@ char	*set_menu_request(
 			ls[k].accel_key = 'Z';
 			ls[k].short_key[0] = '\0';
 			ls[k].n_msg = N_MSG_NULL;
-			sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+			sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 					MSG_MENU_REQUEST_REFRESH,
 					fmt_gold( REQUEST_REFRESH_PRIZE ) );
 			ls[k].call_back = cb_menu_request_refresh;
@@ -2761,7 +2781,7 @@ char	*set_menu_request(
 		ls[k].accel_key = 'Z';
 		ls[k].short_key[0] = '\0';
 		ls[k].n_msg = N_MSG_NULL;
-		sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+		sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 				MSG_MENU_REQUEST_REFRESH,
 				fmt_gold( REQUEST_REFRESH_PRIZE ) );
 		ls[k].call_back = cb_menu_request_refresh;
@@ -2918,7 +2938,7 @@ bool_t	ask_contract_request( request_t *req )
 
 bool_t	ask_cancel_request( request_t *req )
 {
-	char	msg[MENU_MSG_MAX_LEN + 1];
+	char	msg[MENU_MSG_MAX_BYTE + 1];
 	gold_t	penalty;
 	ask_t	ask;
 	sex_t	master_sex;
@@ -2929,7 +2949,7 @@ bool_t	ask_cancel_request( request_t *req )
 
 	penalty = req->prize * REQUEST_PENALTY_RATE / _100_PERCENT;
 
-	sn_printf( msg, MENU_MSG_MAX_LEN,
+	sn_printf( msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_REQUEST_MBR_CANCEL,
 			fmt_gold( penalty ) );
 	ask = exec_menu_ask( msg, ASK_NO, TRUE );
