@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell.c,v 1.179 2008/09/21 00:41:04 bowkenken Exp $
+* $Id: spell.c,v 1.190 2009/06/01 13:47:35 bowkenken Exp $
 ***************************************************************/
 
 #define	SPELL_C
@@ -138,7 +138,7 @@ void	init_spell( void )
 
 		min_len = get_pading_len( MSG( ls[i].n_msg ), max_len );
 
-		sn_printf( ls[i].msg, MENU_MSG_MAX_LEN,
+		sn_printf( ls[i].msg, MENU_MSG_MAX_BYTE,
 				MSG_MENU_SPELL_LS,
 				min_len,
 				MSG( ls[i].n_msg ),
@@ -277,7 +277,6 @@ char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 	bool_t	flg_learn;
 	long	i;
 
-	/**/
 	pre_sel_mbr = static_cb_menu_sel_spell__pre_sel_mbr;
 
 	crsr = get_crsr();
@@ -293,7 +292,9 @@ char	*cb_menu_sel_spell( menu_t **pp, menu_t **dflt )
 	}
 	if( g_sel_mbr == NULL )
 		return STR_MENU_ERR;
+
 	pre_sel_mbr = g_sel_mbr;
+	static_cb_menu_sel_spell__pre_sel_mbr = pre_sel_mbr;
 
 	if( !chk_can_chr_cast_stat( g_sel_mbr ) ){
 		print_msg( FLG_NULL, MSG_ERR_SPELL, g_sel_mbr->name );
@@ -504,6 +505,11 @@ char	*cb_menu_spell( menu_t **pp, menu_t **dflt )
 		return STR_MENU_CANCEL;
 	}
 
+	if( !chk_last_boss_can_spell( g_sel_spell->kind ) ){
+		print_msg( FLG_NULL, MSG_ERR_MENU_SPELL_LAST_BOSS );
+		return STR_MENU_CANCEL;
+	}
+
 	g_dflt_spell[g_sel_mbr->ls_mbr_n][g_sel_spell_abl] = *pp;
 
 	if( chk_flg( g_sel_spell->flg_extent, FLG_EXTENT_NORMAL ) )
@@ -687,6 +693,8 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 		return;
 	if( !chk_can_chr_cast_lev( chr, tab->kind ) )
 		return;
+	if( !chk_last_boss_can_spell( tab->kind ) )
+		return;
 
 	hp = tab->hp;
 	mp = tab->mp;
@@ -818,6 +826,8 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 	} while( 0 );
 
 	if( flg_msg ){
+		play_sound_spell( chr, tab->kind );
+
 		if( fmt == NULL ){
 			print_msg( FLG_NULL, MSG_SPELL,
 					chr->name, tab->name );
@@ -860,6 +870,44 @@ void	chr_cast_spell( chr_t *chr, spell_tab_t *tab, const char *fmt )
 
 /**/
 
+void	play_sound_spell( chr_t *chr, spell_kind_t kind )
+{
+	if( (SPELL_KIND_MAG_MIN_N < kind)
+			&& (kind < SPELL_KIND_MAG_MAX_N) ){
+		call_game_sound_play( SOUND_KIND_SPELL_MAG, 1 );
+	}
+	if( (SPELL_KIND_SOR_MIN_N < kind)
+			&& (kind < SPELL_KIND_SOR_MAX_N) ){
+		call_game_sound_play( SOUND_KIND_SPELL_SOR, 1 );
+	}
+	if( (SPELL_KIND_ENC_MIN_N < kind)
+			&& (kind < SPELL_KIND_ENC_MAX_N) ){
+		call_game_sound_play( SOUND_KIND_SPELL_ENC, 1 );
+	}
+	if( (SPELL_KIND_SUM_MIN_N < kind)
+			&& (kind < SPELL_KIND_SUM_MAX_N) ){
+		call_game_sound_play( SOUND_KIND_SPELL_SUM, 1 );
+	}
+	if( (SPELL_KIND_PRI_MIN_N < kind)
+			&& (kind < SPELL_KIND_PRI_MAX_N) ){
+		call_game_sound_play( SOUND_KIND_SPELL_PRI, 1 );
+	}
+	if( (SPELL_KIND_SHA_MIN_N < kind)
+			&& (kind < SPELL_KIND_SHA_MAX_N) ){
+		call_game_sound_play( SOUND_KIND_SPELL_SHA, 1 );
+	}
+	if( (SPELL_KIND_BAR_MIN_N < kind)
+			&& (kind < SPELL_KIND_BAR_MAX_N) ){
+		call_game_sound_play( SOUND_KIND_SPELL_BAR, 1 );
+	}
+	if( (SPELL_KIND_NIN_MIN_N < kind)
+			&& (kind < SPELL_KIND_NIN_MAX_N) ){
+		call_game_sound_play( SOUND_KIND_SPELL_NIN, 1 );
+	}
+}
+
+/**/
+
 void	chr_cast_spell_normal(
 	chr_t *chr, bool_t flg_item,
 	spell_tab_t *tab, rate_t rate
@@ -967,10 +1015,23 @@ void	chr_cast_spell_blast(
 	else
 		kind = CHR_KIND_NULL;
 
+	if( is_mnstr( chr ) ){
+		if( chk_flg( chr->flg_map, FLG_MAP_CHR_FIND ) ){
+			call_game_sound_play(
+					SOUND_KIND_BLAST_MONSTER, 1 );
+		}
+	} else if( is_mbr( chr ) ){
+		if( chk_flg( chr->flg_map, FLG_MAP_CHR_FIND ) ){
+			call_game_sound_play(
+					SOUND_KIND_BLAST_MEMBER, 1 );
+		}
+	}
+
 	blast = get_blast_spell( tab->kind );
 	blast_str = get_spell_vfx_str( tab->kind );
 	draw_blast( kind, x, y, blast, blast_str );
-	wait_clock( ANIM_FRAME_N_BLAST_STD );
+	if( clip_draw_pos( x, y ) )
+		wait_clock( ANIM_FRAME_N_BLAST_STD );
 
 	flg_actual = chk_flg( get_flg_party(), FLG_PARTY_ACTUAL_FIGHTING );
 
@@ -1000,12 +1061,19 @@ void	chr_cast_spell_blast(
 				p = get_mnstr( xx, yy );
 				if( p == NULL )
 					break;
-				if( !flg_actual ){
-					if( ((mnstr_t *)p)->attitude
-							!= ATTITUDE_ENEMY ){
-						continue;
-					}
+				if( p == chr )
+					continue;
+
+				if( flg_actual )
+					break;
+				if( is_mnstr( chr ) )
+					break;
+				if( ((mnstr_t *)p)->attitude
+						== ATTITUDE_ENEMY ){
+					break;
 				}
+				continue;
+
 				break;
 			case TRGT_KIND_ITEM:
 				p = get_item( xx, yy );
@@ -1034,7 +1102,8 @@ void	chr_cast_spell_blast(
 	end_sync_vfx_num();
 
 	draw_blast( kind, x, y, blast, blast_str );
-	wait_clock( ANIM_FRAME_N_BLAST_STD );
+	if( clip_draw_pos( x, y ) )
+		wait_clock( ANIM_FRAME_N_BLAST_STD );
 
 	xx = x - (blast->xr / 2);
 	yy = y - blast->yr;
@@ -1248,7 +1317,7 @@ void	chr_cast_spell_mass_mnstr(
 
 		if( !chk_find_chr( chr, mns_pp ) )
 			continue;
-		if( !flg_actual )
+		if( !flg_actual && !is_mnstr( chr ) )
 			if( mns_pp->attitude != ATTITUDE_ENEMY )
 				continue;
 
@@ -1277,7 +1346,7 @@ void	chr_cast_spell_mass_mnstr(
 
 		if( !chk_find_chr( chr, mns_pp ) )
 			continue;
-		if( !flg_actual )
+		if( !flg_actual && !is_mnstr( chr ) )
 			if( mns_pp->attitude != ATTITUDE_ENEMY )
 				continue;
 
@@ -1484,7 +1553,12 @@ void	chr_cast_spell_sub(
 #if	(! FLG_SPELL_SANCTUARY)
 	/* ξǤϵʳϤȤɤʤ */
 
-	if( tab->abl != ABL_KIND_PRI ){
+	do {
+		if( get_scene() == SCENE_N_LAST_BOSS )
+			break;
+		if( tab->abl == ABL_KIND_PRI )
+			break;
+
 		if( chk_map_sanctuary( chr->x, chr->y ) ){
 			if( is_mbr( chr ) ){
 				curs_attrset_chr( chr, -1, FALSE );
@@ -1498,7 +1572,9 @@ void	chr_cast_spell_sub(
 		}
 		if( chk_map_sanctuary( x, y ) )
 			return;
-	}
+
+		break;
+	} while( 0 );
 #endif	/* ENABLE_SPELL_SANCTUARY */
 
 	/* ɸ˻̤äƤ뤫å */
@@ -1539,8 +1615,9 @@ void	chr_cast_spell_sub(
 					d_p->name, tab->gold - d_p->gold );
 
 			return;
+		} else {
+			d_p->gold -= tab->gold;
 		}
-		d_p->gold -= tab->gold;
 	}
 
 	/* ʸ뤫å */
@@ -1580,6 +1657,37 @@ void	chr_cast_spell_sub(
 		return;
 	}
 
+	/* ʸ񹳤뤫å */
+
+	do {
+		flg_stat_t	stat;
+		skill_kind_t	skill;
+		long	per;
+
+		stat = cv_spell_to_stat( tab->kind );
+		if( stat == FLG_STAT_NULL )
+			break;
+
+		skill = cv_stat_to_skill_stat( stat );
+		if( skill == SKILL_KIND_NULL )
+			break;
+
+		if( !chk_ena_skill( d_p, skill ) )
+			break;
+
+		per = calc_skill_rate( d_p, skill );
+		if( per_randm( per ) )
+			break;
+
+		curs_attrset_chr( d_p, +1, FALSE );
+		print_msg_find( d_p, FLG_NULL,
+				MSG_RESI_SPELL_SKILL,
+				d_p->name, tab->name );
+		curs_attrset_dflt();
+
+		return;
+	} while( 0 );
+
 	switch( tab->kind ){
 	case SPELL_KIND_NULL:
 		break;
@@ -1605,13 +1713,21 @@ void	chr_cast_spell_sub(
 		fx_recall();
 		break;
 	case SPELL_KIND_KNOCK:
-		fx_knock( get_door( x, y ) );
+		if( trgt_kind == TRGT_KIND_ITEM )
+			chr_open_item( chr, get_item( x, y ) );
+		else
+			fx_knock( get_door( x, y ) );
 		break;
 	case SPELL_KIND_LOCK:
 		fx_lock( get_door( x, y ) );
 		break;
 	case SPELL_KIND_DISARM_TRAP:
-		fx_disarm_trap( get_trap( x, y ), chr );
+		if( trgt_kind == TRGT_KIND_ITEM ){
+			chr_disarm_item_abl( chr, get_item( x, y ),
+					ABL_KIND_MAG, ABL_KIND_INT );
+		} else {
+			fx_disarm_trap( get_trap( x, y ), chr );
+		}
 		break;
 	case SPELL_KIND_DISPEL_MAGIC:
 /*@@@*/
@@ -1656,22 +1772,20 @@ void	chr_cast_spell_sub(
 		fx_detect_mnstr( chr );
 		break;
 	case SPELL_KIND_SENSE_INVISIBLE:
-		fx_std( (chr_t *)p, FX_KIND_SENSE_INVISIBLE );
-		break;
 	case SPELL_KIND_FLY:
-		fx_std( (chr_t *)p, FX_KIND_FLY );
+		fx_std( (chr_t *)p, cv_spell_to_fx( tab->kind ) );
 		break;
 	case SPELL_KIND_FEATHER_FALL:
 /*@@@*/
 		break;
 	case SPELL_KIND_VANISH:
-		fx_std( (chr_t *)p, FX_KIND_VANISH );
+		fx_std( (chr_t *)p, cv_spell_to_fx( tab->kind ) );
 		break;
 	case SPELL_KIND_DARKVISION:
 		fx_darkvision( (chr_t *)p );
 		break;
 	case SPELL_KIND_PASSWALL:
-		fx_std( (chr_t *)p, FX_KIND_PASSWALL );
+		fx_std( (chr_t *)p, cv_spell_to_fx( tab->kind ) );
 		break;
 	case SPELL_KIND_POLYMORPH_OTHER:
 		fx_polymorph( (chr_t *)p );
@@ -1730,7 +1844,7 @@ void	chr_cast_spell_sub(
 /*@@@*/
 		break;
 	case SPELL_KIND_IRON_BODY:
-		fx_std( (chr_t *)p, FX_KIND_IRON_BODY );
+		fx_std( (chr_t *)p, cv_spell_to_fx( tab->kind ) );
 		break;
 	case SPELL_KIND_SPELL_RESISTANCE:
 /*@@@*/
@@ -1739,34 +1853,16 @@ void	chr_cast_spell_sub(
 		fx_std( (chr_t *)p, FX_KIND_COUNTER_MAGIC );
 		break;
 	case SPELL_KIND_STONE:
-		fx_std( (chr_t *)p, FX_KIND_STONE );
-		break;
 	case SPELL_KIND_PARALYZE:
-		fx_std( (chr_t *)p, FX_KIND_PARALYZE );
-		break;
 	case SPELL_KIND_POISON:
-		fx_std( (chr_t *)p, FX_KIND_POISON );
-		break;
 	case SPELL_KIND_CONFUSION:
-		fx_std( (chr_t *)p, FX_KIND_CONFUSION );
-		break;
 	case SPELL_KIND_BLINDNESS:
-		fx_std( (chr_t *)p, FX_KIND_BLIND );
-		break;
 	case SPELL_KIND_SLEEP:
-		fx_std( (chr_t *)p, FX_KIND_SLEEP );
-		break;
 	case SPELL_KIND_SILENCE:
-		fx_std( (chr_t *)p, FX_KIND_SILENCE );
-		break;
 	case SPELL_KIND_FEAR:
-		fx_std( (chr_t *)p, FX_KIND_FEAR );
-		break;
 	case SPELL_KIND_HALLUCINATION:
-		fx_std( (chr_t *)p, FX_KIND_HALLUCINATION );
-		break;
 	case SPELL_KIND_CHARM:
-		fx_std( (chr_t *)p, FX_KIND_CHARM );
+		fx_std( (chr_t *)p, cv_spell_to_fx( tab->kind ) );
 		break;
 	case SPELL_KIND_SOR_MAX_N:
 		break;
@@ -2541,6 +2637,94 @@ bool_t	chk_cast_spell_trgt( spell_kind_t spell, trgt_kind_t trgt )
 
 /**/
 
+fx_kind_t	cv_spell_to_fx( spell_kind_t spell )
+{
+	switch( spell ){
+	case SPELL_KIND_SENSE_INVISIBLE:
+		return FX_KIND_SENSE_INVISIBLE;
+	case SPELL_KIND_FLY:
+		return FX_KIND_FLY;
+	case SPELL_KIND_VANISH:
+		return FX_KIND_VANISH;
+	case SPELL_KIND_PASSWALL:
+		return FX_KIND_PASSWALL;
+	case SPELL_KIND_IRON_BODY:
+		return FX_KIND_IRON_BODY;
+	case SPELL_KIND_COUNTER_MAGIC:
+		return FX_KIND_COUNTER_MAGIC;
+	case SPELL_KIND_STONE:
+		return FX_KIND_STONE;
+	case SPELL_KIND_PARALYZE:
+		return FX_KIND_PARALYZE;
+	case SPELL_KIND_POISON:
+		return FX_KIND_POISON;
+	case SPELL_KIND_CONFUSION:
+		return FX_KIND_CONFUSION;
+	case SPELL_KIND_BLINDNESS:
+		return FX_KIND_BLIND;
+	case SPELL_KIND_SLEEP:
+		return FX_KIND_SLEEP;
+	case SPELL_KIND_SILENCE:
+		return FX_KIND_SILENCE;
+	case SPELL_KIND_FEAR:
+		return FX_KIND_FEAR;
+	case SPELL_KIND_HALLUCINATION:
+		return FX_KIND_HALLUCINATION;
+	case SPELL_KIND_CHARM:
+		return FX_KIND_CHARM;
+	default:
+		break;
+	}
+
+	return FX_KIND_NULL;
+}
+
+/**/
+
+flg_stat_t	cv_spell_to_stat( spell_kind_t spell )
+{
+	switch( spell ){
+	case SPELL_KIND_SENSE_INVISIBLE:
+		return FLG_STAT_SENSE_INVISIBLE;
+	case SPELL_KIND_FLY:
+		return FLG_STAT_FLY;
+	case SPELL_KIND_VANISH:
+		return FLG_STAT_VANISH;
+	case SPELL_KIND_PASSWALL:
+		return FLG_STAT_PASSWALL;
+	case SPELL_KIND_DEATH_SPELL:
+		return FLG_STAT_DEAD;
+	case SPELL_KIND_IRON_BODY:
+		return FLG_STAT_IRON_BODY;
+	case SPELL_KIND_STONE:
+		return FLG_STAT_STONE;
+	case SPELL_KIND_PARALYZE:
+		return FLG_STAT_PARALYZE;
+	case SPELL_KIND_POISON:
+		return FLG_STAT_POISON;
+	case SPELL_KIND_CONFUSION:
+		return FLG_STAT_CONFUSION;
+	case SPELL_KIND_BLINDNESS:
+		return FLG_STAT_BLIND;
+	case SPELL_KIND_SLEEP:
+		return FLG_STAT_SLEEP;
+	case SPELL_KIND_SILENCE:
+		return FLG_STAT_SILENCE;
+	case SPELL_KIND_FEAR:
+		return FLG_STAT_FEAR;
+	case SPELL_KIND_HALLUCINATION:
+		return FLG_STAT_HALLUCINATION;
+	case SPELL_KIND_CHARM:
+		return FLG_STAT_CHARM;
+	default:
+		break;
+	}
+
+	return FLG_STAT_NULL;
+}
+
+/**/
+
 bool_t	chk_bar_limit( chr_t *chr )
 {
 	if( chr == NULL )
