@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: town.c,v 1.149 2009/02/19 00:28:17 bowkenken Exp $
+* $Id: town.c,v 1.153 2009/06/01 05:05:04 bowkenken Exp $
 ***************************************************************/
 
 #define	TOWN_C
@@ -1359,10 +1359,8 @@ bool_t	appear_party_town( void )
 			FACE_MNR_STAIRS_DOWN, &x, &y ) ){
 		return FALSE;
 	}
-	pty->square.x = x;
-	pty->square.y = y;
-	pty->square.pre_x = x;
-	pty->square.pre_y = y;
+	set_square_pos( x, y, FALSE );
+	set_square_pos( x, y, TRUE );
 
 	clr_map_all_mbr();
 	clr_map_all_pet();
@@ -1374,11 +1372,11 @@ bool_t	appear_party_town( void )
 				FLG_STAT_NOT_EXIST | FLG_STAT_DEAD ) )
 			continue;
 
-		nx = pty->square.x + pty->square.chr_pos[n].x;
-		ny = pty->square.y + pty->square.chr_pos[n].y;
+		get_square_mbr_abs_pos( n, &nx, &ny );
 		put_chr( pty->mbr[n], nx, ny );
 	}
 
+	reset_mbr_dir();
 	appear_all_pet();
 
 	next_pos_square( 0 );
@@ -1476,6 +1474,8 @@ bool_t	enter_shop( void )
 	pty = get_party();
 	pet = get_party_pet();
 
+	set_flg_load_game_data( FALSE );
+
 	if( pty->act.kind != ACT_KIND_SHOP )
 		return FALSE;
 
@@ -1529,7 +1529,8 @@ bool_t	enter_shop( void )
 			print_msg( FLG_MSG_ERR, MSG_S,
 					MSG_ERR_NOT_EXIST_ALL_MBR );
 		} else {
-			party_exit_shop( dr_n );
+			if( !get_flg_load_game_data() )
+				party_exit_shop( dr_n );
 			break;
 		}
 	}
@@ -1605,19 +1606,17 @@ void	party_exit_shop( long dr_n )
 	} else {
 		/* ̤˽Ф */
 
-		pty->square.x = x + 1;
-		pty->square.y = y + 1;
-
+		set_square_pos( x + 1, y + 1, FALSE );
 		clr_map_all_mbr();
 
 		for( j = 0; j < MBR_MAX_N; j++ ){
 			long	x, y;
 
-			x = pty->square.x + pty->square.chr_pos[j].x;
-			y = pty->square.y + pty->square.chr_pos[j].y;
+			get_square_mbr_abs_pos( j, &x, &y );
 			put_chr( pty->mbr[j], x, y );
 		}
 
+		reset_mbr_dir();
 		appear_all_pet();
 	}
 
@@ -1626,7 +1625,8 @@ void	party_exit_shop( long dr_n )
 	set_flg_find_all_mnstr();
 	wipe_menu();
 
-	move_crsr_abs( pty->square.x, pty->square.y );
+	get_square_pos( &x, &y, FALSE );
+	move_crsr_abs( x, y );
 
 	if( dun->door[dr_n].mnr != FACE_MNR_SHOP_BAR )
 		add_turn( SHOP_ADD_TURN_N );
@@ -2271,7 +2271,7 @@ bool_t	set_art_name_equip( mbr_t *mbr, item_t *art, equip_kind_t eq )
 		break;
 	}
 	if( eq_name != NULL ){
-		sn_printf( art->art_name, ITEM_ART_NAME_MAX_LEN,
+		sn_printf( art->art_name, ITEM_ART_NAME_MAX_BYTE,
 				MSG_FMT_ART_NAME_EQUIP,
 				get_equip_ttl_max_len(), eq_name,
 				art->name );
